@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 1861 2009-06-28 14:47:41Z hikarin $
+# $Id: BBS.pm 1874 2009-12-01 17:54:35Z hikarin $
 #
 
 package Img0ch::App::BBS;
@@ -472,16 +472,18 @@ sub is_writeable {
         my $args = {
             duplicate_ok => $iCap->can_double_post(),
             ip           => $iApp->{_ip_int},
-            len          => length $iApp->{__param_MESSAGE},
+            digest       => _sha1_b64( $iApp->{__param_MESSAGE} ),
             samba_close  => $samba,
-            samba_ok     => $iCap->can_post_sambaless(),
-            samba_wait   => ( $iConfig->get_int('SambaWait') || 3600 ),
-            serial       => $iApp->{_serial},
-            stamp        => $iApp->{__now},
-            store        => ( $iConfig->get_int('LogStackMAX') || 255 ),
-            timeclose    => $iSetting->get_int('timeclose'),
-            timecount    => $iSetting->get_int('timecount'),
-            throttle_ok  => $iCap->can_throttled_post(),
+            samba_ok     => $iConfig->get('DisableSamba')
+                || $iCap->can_post_sambaless(),
+            samba_wait => ( $iConfig->get_int('SambaWait')   || 3600 ),
+            serial     => $iApp->{_serial},
+            stamp      => $iApp->{__now},
+            store      => ( $iConfig->get_int('LogStackMAX') || 255 ),
+            timeclose  => $iSetting->get_int('timeclose'),
+            timecount  => $iSetting->get_int('timecount'),
+            throttle_ok => $iConfig->get('DisableThrottle')
+                || $iCap->can_throttled_post(),
         };
         defined &{'Img0ch::Filter::Res::write_ok'}
             or require Img0ch::Filter::Res;
@@ -895,17 +897,7 @@ sub trip {
                 }
             }
             else {
-                if ( defined $Digest::SHA1::VERSION
-                    or eval 'require Digest::SHA1' )
-                {
-                    $t = substr Digest::SHA1::sha1_base64($key), 0, 12;
-                }
-                else {
-                    defined $Digest::SHA::PurePerl::VERSION
-                        or require Digest::SHA::PurePerl;
-                    $t = substr Digest::SHA::PurePerl::sha1_base64($key), 0,
-                        12;
-                }
+                $t = substr _sha1_b64($key), 0, 12;
                 $t =~ tr/+/./;
             }
         }
@@ -1297,6 +1289,20 @@ sub _acceptable {
     return 0;
 }
 
+sub _sha1_b64 {
+    my ($text) = @_;
+    if ( defined $Digest::SHA1::VERSION
+        or eval 'require Digest::SHA1' )
+    {
+        return Digest::SHA1::sha1_base64($text);
+    }
+    else {
+        defined $Digest::SHA::PurePerl::VERSION
+            or require Digest::SHA::PurePerl;
+        return Digest::SHA::PurePerl::sha1_base64($text);
+    }
+}
+
 sub redirect_success {
     my ($iApp)   = @_;
     my $iBBS     = $iApp->{__bbs};
