@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: DNSBL.pm 1827 2009-04-08 15:24:43Z hikarin $
+# $Id: DNSBL.pm 1865 2009-09-13 13:38:42Z hikarin $
 #
 
 package Img0ch::Plugin::Module::DNSBL;
@@ -24,12 +24,12 @@ use strict;
 my $available_dnsbl = {
     'bbq'        => 'niku.2ch.net',
     'bbx'        => 'bbx.2ch.net',
-    'dsbl'       => 'list.dsbl.org',
     'rbl'        => 'all.rbl.jp',
     'spamcop'    => 'bl.spamcop.net',
     'spamhaus'   => 'zen.spamhaus.org',
     'empty'      => 'bsb.empty.us',
     'spamlookup' => 'bsb.spamlookup.net',
+    'livedoor'   => 'dnsbl.spam-champuru.livedoor.com',
 };
 
 sub get_all_dnsbl {
