@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,13 +14,12 @@
 # *  limitations under the License.
 # */
 #
-# $Id: ClamAV.pm 363 2007-03-16 15:11:10Z hikarin $
+# $Id: ClamAV.pm 1872 2009-11-10 16:15:34Z hikarin $
 #
 
 package Img0ch::Plugin::Upload::ClamAV;
 
 use strict;
-use ClamAV::Client qw();
 
 sub check {
     my ($iApp)  = @_;
@@ -28,12 +27,15 @@ sub check {
     my $iConfig = $iKernel->get_config();
 
     my $ud_socket = $iConfig->get('clamav.socket_name');
-    my @args      = $ud_socket
+    my @args
+        = $ud_socket
         ? ( socket_name => $ud_socket )
         : (
         socket_host => $iConfig->get('clamav.tcp_host'),
         socket_port => $iConfig->get_int('clamav.tcp_port')
         );
+
+    defined $ClamAV::Client::VERSION or require ClamAV::Client;
     my $clamav = ClamAV::Client->new(@args);
     $clamav->ping()
         or $iKernel->throw_exception('ClamAV DAEMON NOT ACTIVATE');
