@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: CS.pm 363 2007-03-16 15:11:10Z hikarin $
+# $Id: CS.pm 1826 2009-04-08 15:23:25Z hikarin $
 #
 
 package Img0ch::Template::CS;
@@ -57,9 +57,11 @@ sub param {
 
 sub render {
     my ($iTemplate) = @_;
-    my $cs = ClearSilver::CS->new( $iTemplate->{__hdf} );
-    $cs->parseFile( $iTemplate->{__file} )
-        or die 'ClearSilver RENDERING ERROR: ', $!;
+    my $cs          = ClearSilver::CS->new( $iTemplate->{__hdf} );
+    my $file        = $iTemplate->{__file};
+    $cs->parseFile($file)
+        or die 'ClearSilver RENDERING ERROR AT PARSING(OR RENDERING) ', $file,
+        ': ', $!, "\n";
     \$cs->render();
 }
 
@@ -70,14 +72,14 @@ my $switch = {
         my ( $hdf, $key, $val ) = @_;
         my $index = 0;
         for my $value (@$val) {
-            _hdf_setValue( $hdf, "${key}.${index}", $value );
+            _hdf_setValue( $hdf, join( '.', $key, $index ), $value );
             $index++;
         }
     },
     'HASH' => sub {
         my ( $hdf, $key, $val ) = @_;
         while ( my ( $k, $v ) = each %$val ) {
-            _hdf_setValue( $hdf, "${key}.${k}", $v );
+            _hdf_setValue( $hdf, join( '.', $key, $k ), $v );
         }
     },
     'SCALAR' => sub {
