@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Plugin.pm 1481 2007-10-24 14:13:30Z hikarin $
+# $Id: Plugin.pm 1826 2009-04-08 15:23:25Z hikarin $
 #
 
 package Zeromin::Plugin;
@@ -365,7 +365,7 @@ sub filter_with_page {
     my $class = [];
     map { push @$class, { name => $_ } } sort keys %$classes;
 
-    require Data::Page;
+    defined $Data::Page::VERSION or require Data::Page;
     my $page = Data::Page->new( scalar @$content, $item_per_page, $offset );
     return ( [ $page->splice($content) ], $page, $class );
 }
@@ -525,7 +525,7 @@ sub _switch {
         = $class =~ /\A(\d+)\z/xms
         ? $zPlugin->get_plugin($1)
         : _split($class);
-    exists $zPlugin->{__load}->{$cls}         or return 0;
+    exists $zPlugin->{__load}->{$cls} or return 0;
     exists $zPlugin->{__load}->{$cls}->{$mtd} or return 0;
     $zPlugin->{__load}->{$cls}->{$mtd}->[2] = $bit;
     return 1;
