@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: meta.pm 1481 2007-10-24 14:13:30Z hikarin $
+# $Id: meta.pm 1782 2008-10-26 13:53:00Z hikarin $
 #
 
 package Zeromin2::App::meta;
@@ -105,11 +105,9 @@ sub save_thread_end {
     my $date     = $iRequest->param('date');
     $date =~ /\AOver\s+\d+\s+Thread\z/xms or return $zApp->return_value(2);
 
-    my $from
-        = $iKernel->get_encoded_str( $iRequest->param( 'FROM', 1 ), 'utf8' );
-    my $mail = $iKernel->get_encoded_str( $iRequest->param('mail'), 'utf8' );
-    my $text = $iKernel->get_encoded_str( $iRequest->param( 'MESSAGE', 1 ),
-        'utf8' );
+    my $from = $iRequest->param( 'FROM',    1 );
+    my $mail = $iRequest->param( 'mail',    1 );
+    my $text = $iRequest->param( 'MESSAGE', 1 );
     $text =~ s/\r\n/\n/gxms;
     $text =~ s/\n/<br>/gxms;
 
@@ -125,10 +123,7 @@ sub _save_meta {
     $zApp->check_csrf() or return $zApp->return_value(1);
     $zApp->privilege( $privilege, 1 ) or return $zApp->return_value(1);
 
-    my $text
-        = $zApp->kernel()
-        ->get_encoded_str( $zApp->request()->param( 'content', 1 ),
-        undef, 'utf8' );
+    my $text = $zApp->request()->param( 'content', 1 );
     $text =~ s/\r\n/\n/gxms;
 
     Zeromin::Metadata->new( $zApp->bbs() )->$method( \$text );
