@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: upload.pm 1613 2007-11-23 12:49:53Z hikarin $
+# $Id: upload.pm 1781 2008-10-26 13:52:37Z hikarin $
 #
 
 package Zeromin2::App::upload;
@@ -35,7 +35,7 @@ sub load_tag {
     $zApp->privilege( 'can_abone_res', 1 )
         or return $zApp->return_value( 1, [] );
 
-    defined &{'Img0ch::Upload::Tag::new'} or require Img0ch::Upload::Tag;
+    Img0ch::Kernel->load_module('Img0ch::Upload::Tag');
     my $iBBS  = $zApp->bbs();
     my $key   = $zApp->key();
     my $resno = $zApp->request()->param_int('resno');
@@ -71,7 +71,7 @@ sub load_ngtag {
     $zApp->privilege( 'can_enter_control_section', 1 )
         or return $zApp->return_value( 1, [] );
 
-    defined &{'Img0ch::Upload::Tag::new'} or require Img0ch::Upload::Tag;
+    Img0ch::Kernel->load_module('Img0ch::Upload::Tag');
     my $iBBS  = $zApp->bbs();
     my $key   = $zApp->key();
     my $resno = $zApp->request()->param_int('resno');
@@ -91,11 +91,11 @@ sub load_ngtag {
 
 sub save_ngtag {
     my ($zApp) = @_;
-    $zApp->privilege( 'can_add_ngword',         1 )
+    $zApp->privilege( 'can_add_ngword', 1 )
         or $zApp->privilege( 'can_edit_ngword', 1 )
         or return $zApp->return_value(1);
 
-    defined &{'Img0ch::Upload::Tag::new'} or require Img0ch::Upload::Tag;
+    Img0ch::Kernel->load_module('Img0ch::Upload::Tag');
     my $iBBS     = $zApp->bbs();
     my $iRequest = $zApp->request();
     my $key      = $zApp->key();
@@ -115,7 +115,8 @@ sub _load_poll {
     $zApp->privilege( 'can_abone_res', 1 )
         or return $zApp->return_value( 1, [] );
 
-    defined &{'Img0ch::Upload::Poll::new'}   or require Img0ch::Upload::Poll;
+    Img0ch::Kernel->load_module('Img0ch::Upload::Poll');
+    Img0ch::Kernel->load_module('Img0ch::Upload::Removed');
     defined &{'Zeromin2::Util::format_date'} or require Zeromin2::Util;
     my $iBBS     = $zApp->bbs();
     my $key      = $zApp->key();
@@ -125,8 +126,8 @@ sub _load_poll {
     my $param    = _load_common( $zApp, $iBBS, $key, $resno );
 
     my $iUPoll = Img0ch::Upload::Poll->new( $iBBS, $key );
-    my $polls  = $iUPoll->get( $resno,             $argument->{name} );
-    my $date   = $argument->{date};
+    my $polls = $iUPoll->get( $resno, $argument->{name} );
+    my $date = $argument->{date};
     for my $one (@$polls) {
         $one->{comment}
             = $iKernel->get_encoded_str( $one->{comment}, 'utf8', $encoding );
@@ -202,7 +203,8 @@ sub load_removed_file_hash {
     my ($zApp) = @_;
     $zApp->privilege('can_remove_thread') or return $zApp->return_value(1);
 
-    defined &{'Img0ch::Upload::Poll::new'}   or require Img0ch::Upload::Poll;
+    Img0ch::Kernel->load_module('Img0ch::Upload::Poll');
+    Img0ch::Kernel->load_module('Img0ch::Upload::Removed');
     defined &{'Zeromin2::Util::format_date'} or require Zeromin2::Util;
 
     my $iURemoved = Img0ch::Upload::Removed->new( $zApp->kernel() );
@@ -229,14 +231,13 @@ sub load_removed_file_hash {
 
 sub remove_removed_file_hash {
     my ($zApp) = @_;
-    $zApp->check_csrf()                   or return $zApp->return_value(1);
+    $zApp->check_csrf() or return $zApp->return_value(1);
     $zApp->privilege('can_remove_thread') or return $zApp->return_value(1);
 
     my @param = $zApp->request()->param('hash');
     scalar @param or return $zApp->return_value(2);
 
-    defined &{'Img0ch::Upload::Removed::new'}
-        or require Img0ch::Upload::Removed;
+    Img0ch::Kernel->load_module('Img0ch::Upload::Removed');
     my $iURemoved = Img0ch::Upload::Removed->new( $zApp->kernel() );
     my $status    = {};
 
@@ -261,7 +262,7 @@ sub remove_review { _remove_poll( { name => 'STAR', log => 'REVIEW' }, @_ ) }
 
 sub _remove_poll {
     my ( $argument, $zApp ) = @_;
-    $zApp->check_csrf()                 or return $zApp->return_value(1);
+    $zApp->check_csrf() or return $zApp->return_value(1);
     $zApp->privilege('can_remove_poll') or return $zApp->return_value(1);
 
     my $iRequest = $zApp->request();
@@ -272,7 +273,7 @@ sub _remove_poll {
     my $tag   = $argument->{name};
     my $log   = $argument->{log};
 
-    defined &{'Img0ch::Upload::Poll::new'} or require Img0ch::Upload::Poll;
+    Img0ch::Kernel->load_module('Img0ch::Upload::Poll');
     my $zBBS   = $zApp->bbs();
     my $bbs    = $zBBS->get_name();
     my $key    = $zApp->key();
@@ -304,10 +305,10 @@ sub _remove_poll {
 
 sub update_removed_upload_files_as_json {
     my ($zApp) = @_;
-    $zApp->check_csrf()                      or return $zApp->return_value(1);
+    $zApp->check_csrf() or return $zApp->return_value(1);
     $zApp->privilege('can_recreate_subject') or return $zApp->return_value(1);
 
-    defined &{'Zeromin::Upload::new'} or require Zeromin::Upload;
+    Img0ch::Kernel->load_module('Zeromin::Upload');
     my $zUser   = $zApp->user();
     my $iKernel = $zApp->kernel();
     my @param   = $zApp->request()->param('board');
@@ -338,7 +339,7 @@ sub remove_all_review {
 
 sub _remove_all_poll {
     my ( $argument, $zApp ) = @_;
-    $zApp->check_csrf()                 or return $zApp->return_value(1);
+    $zApp->check_csrf() or return $zApp->return_value(1);
     $zApp->privilege('can_remove_poll') or return $zApp->return_value(1);
 
     my $iRequest = $zApp->request();
@@ -346,7 +347,7 @@ sub _remove_all_poll {
     my $tag      = $argument->{name};
     my $log      = $argument->{log};
 
-    defined &{'Img0ch::Upload::Poll::new'} or require Img0ch::Upload::Poll;
+    Img0ch::Kernel->load_module('Img0ch::Upload::Poll');
     my $zBBS   = $zApp->bbs();
     my $bbs    = $zBBS->get_name();
     my $key    = $zApp->key();
@@ -368,10 +369,10 @@ sub remove_all_tag_name { _remove_tag_name( 1, @_ ) }
 
 sub _remove_tag_name {
     my ( $remove_all_tag, $zApp ) = @_;
-    $zApp->check_csrf()                 or return $zApp->return_value(1);
+    $zApp->check_csrf() or return $zApp->return_value(1);
     $zApp->privilege('can_remove_poll') or return $zApp->return_value(1);
 
-    defined &{'Img0ch::Upload::Tag::new'} or require Img0ch::Upload::Tag;
+    Img0ch::Kernel->load_module('Img0ch::Upload::Tag');
     my $iBBS     = $zApp->bbs();
     my $iUTag    = Img0ch::Upload::Tag->new($iBBS);
     my $bbs      = $iBBS->get_name();
@@ -410,10 +411,10 @@ sub _remove_tag_name {
 
 sub remove_tag_by_resno {
     my ($zApp) = @_;
-    $zApp->check_csrf()                 or return $zApp->return_value(1);
+    $zApp->check_csrf() or return $zApp->return_value(1);
     $zApp->privilege('can_remove_poll') or return $zApp->return_value(1);
 
-    defined &{'Img0ch::Upload::Tag::new'} or require Img0ch::Upload::Tag;
+    Img0ch::Kernel->load_module('Img0ch::Upload::Tag');
     my $iBBS  = $zApp->bbs();
     my $bbs   = $iBBS->get_name();
     my $iUTag = Img0ch::Upload::Tag->new($iBBS);
